@@ -2,9 +2,11 @@
 #include <stdlib.h>
 #include <gtk/gtk.h>
 #include <hildon/hildon.h>
+#include <gmodule.h>
 
 #include "connection-switcher-statusbar.h"
-#include <nm_main_dialog.h>
+/*#include <nm_main_dialog.h>*/
+/*#include <dlfcn.h>*/
 
 #define CONNECTION_SWITCHER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE (obj, \
                             TYPE_CONNECTION_SWITCHER, ConnectionSwitcherPrivate))
@@ -15,7 +17,7 @@ struct _ConnectionSwitcherPrivate
     gpointer data;
 };
 
-HD_DEFINE_PLUGIN_MODULE (ConnectionSwitcher, connection_switcher, HD_TYPE_STATUS_MENU_ITEM);
+HD_DEFINE_PLUGIN_MODULE (ConnectionSwitcher, connection_switcher, HD_TYPE_STATUS_MENU_ITEM)
 
 static void connection_switcher_cb (gpointer, gpointer);
 
@@ -73,15 +75,13 @@ connection_switcher_init (ConnectionSwitcher *plugin)
     gtk_widget_show (GTK_WIDGET (plugin));
 }
 
+static gboolean run(gpointer data) {
+    system("/usr/sbin/pc-connectivity-manager 2");
+}
+
 static void 
 connection_switcher_cb (gpointer instance, gpointer self) 
 {
-    GtkWidget *dialog;
-    dialog = nm_main_dialog_new();
-
-    nm_main_dialog_run(NM_MAIN_DIALOG(dialog), NM_STATUS_MENU);
-
-    /* Free the dialog (and it's children) */
-    gtk_widget_destroy(GTK_WIDGET(dialog));
+    g_idle_add(run, NULL);
 }
 
